@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.10.6');
+use version; our $VERSION = qv('v0.12.4');
 
 use 5.010;
 use	Moose;
@@ -17,20 +17,20 @@ use Types::Standard qw(
 		CodeRef				Int				HasMethods
 		Bool
     );
-use	MooseX::ShortCut::BuildInstance v1.8 qw( build_instance should_re_use_classes );
+use	MooseX::ShortCut::BuildInstance 1.028 qw( build_instance should_re_use_classes );
 should_re_use_classes( 1 );
 use lib	'../../../../lib',;
 ###LogSD	use Log::Shiras::Telephone;
 ###LogSD	use Log::Shiras::UnhideDebug;
 with 	'Spreadsheet::XLSX::Reader::LibXML::LogSpace';
 ###LogSD	use Log::Shiras::UnhideDebug;
-use	Spreadsheet::XLSX::Reader::LibXML::Error v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::FmtDefault v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::ParseExcelFormatStrings v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet v0.5;
-use	Spreadsheet::XLSX::Reader::LibXML::Types v0.5 qw( XLSXFile ParserType );
+use	Spreadsheet::XLSX::Reader::LibXML::Error;
+use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles;
+use	Spreadsheet::XLSX::Reader::LibXML::FmtDefault;
+use	Spreadsheet::XLSX::Reader::LibXML::ParseExcelFormatStrings;
+use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings;
+use	Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
+use	Spreadsheet::XLSX::Reader::LibXML::Types qw( XLSXFile ParserType );
 
 #########1 Dispatch Tables    3#########4#########5#########6#########7#########8#########9
 
@@ -167,13 +167,6 @@ has group_return_type =>(
 
 #########1 Public Methods     3#########4#########5#########6#########7#########8#########9
 
-
-###############################################################################
-#
-# parse()
-#
-# A convenience method to duplicate Spreadsheet::ParseExcel processes
-
 sub parse{
 
     my ( $self, $file_name, $formatter ) = @_;
@@ -300,7 +293,9 @@ has _styles_instance =>(
 		writer		=> '_set_styles_instance',
 		clearer		=> '_clear_styles',
 		predicate	=> '_has_styles_file',
-		handles		=>[ 'get_format_position', 'set_defined_excel_format_list' ],
+		handles		=>[qw(
+			get_format_position	set_defined_excel_format_list change_output_encoding
+		) ],
 	);
 
 has _calc_chain_instance =>(
@@ -365,14 +360,6 @@ has _worksheet_superclass =>(
 	);
 
 #########1 Private Methods    3#########4#########5#########6#########7#########8#########9
-	
-	
-
-###########################################################################################
-#
-# _build_file()
-#
-# Unzip the .xlsx file and extract the generic information into perl data structures
 
 sub _build_file{
 
@@ -461,19 +448,6 @@ sub _build_file{
 	return $self;
 }
 
-
-###############################################################################
-#
-# _check_if_ole_file()
-#
-# Check if the file is an OLE compound doc. This can happen in a few cases.
-# This first is when the file is xls and not xlsx. The second is when the
-# file is an encrypted xlsx file. We also handle the case of unknown OLE
-# file types.
-#
-# Porting note. As a lightweight test you can check for OLE files by looking
-# for the magic number 0xD0CF11E0 (docfile0) at the start of the file.
-#
 sub _check_if_ole_file {
 
     my ( $self, $file_name ) = @_;
@@ -615,7 +589,6 @@ sub _load_doc_props_file{
 		#~ )
 	);
 	###LogSD	$phone->talk( level => 'trace', message => [ "Current object:", $self ] );
-	#~ my $wait = <>;
 }
 
 sub _set_shared_worksheet_files{
@@ -781,8 +754,6 @@ The following uses the 'TestBook.xlsx' file found in the t/test_files/ folder
 	# 85: Unformatted = 40944
 	###########################
 
-
-
 =head1 DESCRIPTION
 
 This is another module for parsing Excel 2007+ workbooks.  The goal of this package is 
@@ -1032,10 +1003,10 @@ B<Range:> The minimum list of methods to implement for your own instance is;
 	error set_error clear_error set_warnings if_warn
 
 B<attribute methods> Methods provided to adjust this attribute
-		
-=back
 
-=head4 get_error_inst
+=over
+
+=B<get_error_inst>
 
 =over
 
@@ -1043,7 +1014,7 @@ B<Definition:> returns this instance
 
 =back
 
-=head4 error
+B<error>
 
 =over
 
@@ -1051,7 +1022,7 @@ B<Definition:> Used to get the most recently logged error
 
 =back
 
-=head4 set_error
+B<set_error>
 
 =over
 
@@ -1059,7 +1030,7 @@ B<Definition:> used to set a new error string
 
 =back
 
-=head4 clear_error
+B<clear_error>
 
 =over
 
@@ -1067,7 +1038,7 @@ B<Definition:> used to clear the current error string in this attribute
 
 =back
 
-=head4 set_warnings
+B<set_warnings>
 
 =over
 
@@ -1075,13 +1046,17 @@ B<Definition:> used to turn on or off real time warnings when errors are set
 
 =back
 
-=head4 if_warn
+B<if_warn>
 
 =over
 
 B<Definition:> a method mostly used to extend this package and see if warnings 
 should be emitted.
 
+=back
+		
+=back
+
 =back
 
 =head3 file_name
@@ -1097,9 +1072,9 @@ B<Range> any unincrypted xlsx file that can be opened in Microsoft Excel
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 set_file_name
+B<set_file_name>
 
 =over
 
@@ -1107,7 +1082,7 @@ B<Definition:> change the set file name (this will reboot the workbook instance)
 
 =back
 
-=head4 has_file_name
+B<has_file_name>
 
 =over
 
@@ -1115,6 +1090,10 @@ B<Definition:> this is fundamentally a way to see if the workbook loaded correct
 
 =back
 
+=back
+
+=back
+
 =head3 file_creator
 
 =over
@@ -1129,9 +1108,9 @@ B<Range> A string
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 creator
+B<creator>
 
 =over
 
@@ -1139,6 +1118,10 @@ B<Definition:> returns the name of the file creator
 
 =back
 
+=back
+
+=back
+
 =head3 file_date_created
 
 =over
@@ -1153,9 +1136,9 @@ B<Range> A timestamp string (ISO ish)
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 date_created
+B<date_created>
 
 =over
 
@@ -1163,6 +1146,10 @@ B<Definition:> returns the date the file was created
 
 =back
 
+=back
+
+=back
+
 =head3 file_modified_by
 
 =over
@@ -1177,9 +1164,9 @@ B<Range> A string
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 modified_by
+B<modified_by>
 
 =over
 
@@ -1187,6 +1174,10 @@ B<Definition:> returns the user name of the person who last modified the file
 
 =back
 
+=back
+
+=back
+
 =head3 file_date_modified
 
 =over
@@ -1201,9 +1192,9 @@ B<Range> A timestamp string (ISO ish)
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 date_modified
+B<date_modified>
 
 =over
 
@@ -1211,6 +1202,10 @@ B<Definition:> returns the date when the file was last modified
 
 =back
 
+=back
+
+=back
+
 =head3 sheet_parser
 
 =over
@@ -1224,9 +1219,9 @@ B<Range> 'reader'
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 set_parser_type
+B<set_parser_type>
 
 =over
 
@@ -1234,7 +1229,7 @@ B<Definition:> the way to change the parser type
 
 =back
 
-=head4 get_parser_type
+B<get_parser_type>
 
 =over
 
@@ -1242,6 +1237,10 @@ B<Definition:> returns the currently set parser type
 
 =back
 
+=back
+
+=back
+
 =head3 count_from_zero
 
 =over
@@ -1256,9 +1255,9 @@ B<Range> 1 = counting from zero like Spreadsheet::ParseExcel,
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 counting_from_zero
+B<counting_from_zero>
 
 =over
 
@@ -1266,7 +1265,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 set_count_from_zero
+B<set_count_from_zero>
 
 =over
 
@@ -1274,6 +1273,10 @@ B<Definition:> a way to change the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 file_boundary_flags
 
 =over
@@ -1291,9 +1294,9 @@ B<Range> 1 = return 'EOR' or 'EOF' flags as appropriate,
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 boundary_flag_setting
+B<boundary_flag_setting>
 
 =over
 
@@ -1301,7 +1304,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 change_boundary_flag
+B<change_boundary_flag>
 
 =over
 
@@ -1309,6 +1312,10 @@ B<Definition:> a way to change the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 empty_is_end
 
 =over
@@ -1326,9 +1333,9 @@ max sheet column
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 is_empty_the_end
+B<is_empty_the_end>
 
 =over
 
@@ -1336,7 +1343,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 set_empty_is_end
+B<set_empty_is_end>
 
 =over
 
@@ -1344,6 +1351,10 @@ B<Definition:> a way to set the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 from_the_edge
 
 =over
@@ -1361,9 +1372,9 @@ the first row and first column with data
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 set_from_the_edge
+B<set_from_the_edge>
 
 =over
 
@@ -1371,6 +1382,10 @@ B<Definition:> a way to set the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 default_format_list
 
 =over
@@ -1389,9 +1404,9 @@ way in.
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_default_format_list
+B<get_default_format_list>
 
 =over
 
@@ -1399,7 +1414,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 set_default_format_list
+B<set_default_format_list>
 
 =over
 
@@ -1407,6 +1422,10 @@ B<Definition:> a way to set the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 format_string_parser
 
 =over
@@ -1420,9 +1439,9 @@ B<Range> a L<Moose> role with the method 'parse_excel_format_string'
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_format_string_parser
+B<get_format_string_parser>
 
 =over
 
@@ -1430,7 +1449,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 set_format_string_parser
+B<set_format_string_parser>
 
 =over
 
@@ -1438,6 +1457,10 @@ B<Definition:> a way to set the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head3 group_return_type
 
 =over
@@ -1459,9 +1482,9 @@ the formatted value stored in the excel cell
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_group_return_type
+B<get_group_return_type>
 
 =over
 
@@ -1469,7 +1492,7 @@ B<Definition:> a way to check the current attribute setting
 
 =back
 
-=head4 set_group_return_type
+B<set_group_return_type>
 
 =over
 
@@ -1477,17 +1500,26 @@ B<Definition:> a way to set the current attribute setting
 
 =back
 
+=back
+
+=back
+
 =head1 BUILD / INSTALL from Source
+
+B<1.> Ensure that you have the libxml2 and libxml2-dev libraries installed using 
+your favorite package installer
+
+http://xmlsoft.org/
 	
-B<1.> Download a compressed file with the code
+B<2.> Download a compressed file with the code
 	
-B<2.> Extract the code from the compressed file.  If you are using tar this should work:
+B<3.> Extract the code from the compressed file.  If you are using tar this should work:
 
         tar -zxvf Spreadsheet-XLSX-Reader-LibXML-v0.xx.tar.gz
 
-B<3.> Change (cd) into the extracted directory
+B<4.> Change (cd) into the extracted directory
 
-B<4.> Run the following
+B<5.> Run the following
 
 =over
 
@@ -1521,13 +1553,20 @@ L<github Spreadsheet::XLSX::Reader::LibXML/issues|https://github.com/jandrew/Spr
 
 =over
 
-B<1.> Add a pivot table reader (Not just read the values from the sheet)
+B<1.> Build L<Alien::LibXML::Devel> to load the libxml2-devel libraries from source and 
+require that and L<Alien::LibXML> in the build file. So all needed requirements for L<XML::LibXML> 
+are met
 
-B<2.> Add calc chain methods
+This includes the libxml2 and libxml2-dev libraries
 
-B<3.> Add more exposure to workbook formatting methods
+B<2.> Add a pivot table reader (Not just read the values from the sheet)
+
+B<3.> Add calc chain methods
+
+B<4.> Add more exposure to workbook formatting methods
+
+B<5.> Build a DOM parser alternative for the sheets
 
-B<4.> Build a DOM parser alternative for the sheets
 (Theoretically faster than the reader but uses more memory)
 
 =back
@@ -1580,6 +1619,8 @@ L<Carp>- cluck
 
 L<XML::LibXML>
 
+L<Clone>
+
 L<DateTimeX::Format::Excel>
 
 L<DateTime::Format::Flexible>
