@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::Cell;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::Cell::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.10.6');
+use version; our $VERSION = qv('v0.12.4');
 
 use 5.010;
 use Moose;
@@ -11,14 +11,14 @@ use MooseX::HasDefaults::RO;
 use Types::Standard qw(
 		Str					InstanceOf				HashRef
 		Enum				HasMethods				ArrayRef
-		Int					Maybe
+		Int					Maybe					CodeRef
     );
 
 use lib	'../../../../../lib';
 ###LogSD	use Log::Shiras::Telephone;
 ###LogSD	use Log::Shiras::UnhideDebug;
 with	'Spreadsheet::XLSX::Reader::LibXML::LogSpace';
-use	Spreadsheet::XLSX::Reader::LibXML::Types v0.5 qw(
+use	Spreadsheet::XLSX::Reader::LibXML::Types qw(
 		CellID
 	);
 
@@ -35,8 +35,8 @@ has	error_inst =>(
 	);
 
 has cell_unformatted =>(
-		isa		=> Maybe[Str],
-		reader	=> 'unformatted',
+		isa			=> Maybe[Str],
+		reader		=> '_unformatted',
 		predicate	=> 'has_unformatted',
 	);
 
@@ -118,6 +118,12 @@ has cell_hyperlink =>(
 		predicate	=> 'has_hyperlink',
 	);
 
+has unformatted_converter =>(
+		isa			=> CodeRef,
+		reader		=> '_convert_output',
+		required	=> 1,
+	);
+
 has cell_coercion =>(
 		isa			=> HasMethods[ 'assert_coerce', 'display_name' ],
 		reader		=> 'get_coercion',
@@ -131,13 +137,32 @@ has cell_coercion =>(
 
 #########1 Public Methods     3#########4#########5#########6#########7#########8#########9
 
+sub unformatted{
+	my( $self, ) 	= @_;
+	###LogSD	my	$phone = Log::Shiras::Telephone->new(
+	###LogSD					name_space 	=> $self->get_log_space .  '::unformatted', );
+	###LogSD		$phone->talk( level => 'debug', message => [
+	###LogSD			"Attempting to return the unformatted value of the cell" ] );
+	###LogSD		$phone->talk( level => 'trace', message => [ "Cell:", $self ] );
+	
+	# check if empty
+	return undef if !$self->has_unformatted;
+	
+	# get the value
+	my	$unformatted	= $self->_unformatted;
+	###LogSD	$phone->talk( level => 'debug', message => [ "unformatted:", $unformatted ] );
+	my	$converter = $self->_convert_output;
+	$unformatted = $converter->( $unformatted );
+	###LogSD	$phone->talk( level => 'debug', message => [ "converted:", $unformatted ] );
+	return $unformatted;
+}
+
 sub value{
 	my( $self, ) 	= @_;
 	###LogSD	my	$phone = Log::Shiras::Telephone->new(
 	###LogSD					name_space 	=> $self->get_log_space .  '::value', );
 	###LogSD		$phone->talk( level => 'debug', message => [
-	###LogSD			"Attempting to return the value of the cell formatted to " .
-	###LogSD			$self->format_name ] );
+	###LogSD			'Reached the -value- function' ] );
 	###LogSD		$phone->talk( level => 'trace', message => [ "Cell:", $self ] );
 	my	$formatted;
 	my	$unformatted	= $self->unformatted;
@@ -148,6 +173,9 @@ sub value{
 	}elsif( $unformatted eq '' ){
 		$self->set_error( "The cell has the empty string for a value" );
 	}else{
+		###LogSD	$phone->talk( level => 'debug', message => [
+		###LogSD		"Attempting to return the value of the cell formatted to " .
+		###LogSD		(($self->has_coercion) ? $self->coercion_name : 'No conversion available' ) ] );
 		eval '$formatted = $self->get_coercion->assert_coerce( $unformatted )';
 		if( $@ ){
 			$self->set_error( $@ );
@@ -231,12 +259,42 @@ as a standalone class just fill in the L<Attributes|/Attributes> below.
 These are methods used to transform data stored in the L<Attributes|/Attributes> 
 (not just return it directly).
 
+=head3 unformatted
+
+=over
+
+B<Definition:> Returns the unformatted value of the cell transformed with the 
+L<change_output_encoding|/Spreadsheet::XLSX::Reader::LibXML::FmtDefault/change_output_encoding> 
+method.
+
+B<Accepts:>Nothing
+
+B<Returns:> the cell value processed by the encoding conversion
+
+=back
+
+=head3 has_unformatted
+
+=over
+
+B<Definition:> This is a predicate method to determine if the cell had any value stored in it.  
+Sometimes this class will be generated by the 
+L<Worksheet|Spreadsheet::XLSX::Reader::LibXML::Worksheet> class when there is cell formatting but 
+no value.  Ex. Merged cells store the value in the left upper corner of the merged area but have 
+cell specific formatting for all cells in the merge area.
+
+B<Accepts:>Nothing
+
+B<Returns:> True if the cell holds a value
+
+=back
+
 =head3 value
 
 =over
 
 B<Definition:> Returns the formatted value of the cell transformed from the 
-L<unformatted|/cell_unformatted> string. This method uses the conversion stored in the
+L<unformatted|/unformatted> string. This method uses the conversion stored in the
 L<cell_conversion|/cell_conversion> attribute.  If there is no format/conversion set 
 then this will return the unformatted value. Any failures to process this value can be 
 retrieved with L<$self-E<gt>error|/error>.
@@ -271,12 +329,12 @@ attributes set as;
 B<Range:> The minimum list of methods to implement for your own instance is;
 
 	error set_error clear_error set_warnings if_warn
-		
-=back
 
 B<attribute methods> Methods provided to adjust this attribute
 
-=head4 get_error_inst
+=over
+
+B<get_error_inst>
 
 =over
 
@@ -284,7 +342,7 @@ B<Definition:> returns this instance
 
 =back
 
-=head4 error
+B<error>
 
 =over
 
@@ -292,7 +350,7 @@ B<Definition:> Used to get the most recently logged error
 
 =back
 
-=head4 set_error
+B<set_error>
 
 =over
 
@@ -300,7 +358,7 @@ B<Definition:> used to set a new error string
 		
 =back
 
-=head4 clear_error
+B<clear_error>
 
 =over
 
@@ -308,7 +366,7 @@ B<Definition:> used to clear the current error string in this attribute
 		
 =back
 
-=head4 set_warnings
+B<set_warnings>
 
 =over
 
@@ -316,7 +374,7 @@ B<Definition:> used to turn on or off real time warnings when errors are set
 		
 =back
 
-=head4 if_warn
+B<if_warn>
 
 =over
 
@@ -325,35 +383,34 @@ should be emitted.
 		
 =back
 
+=back
+
+=back
+
 =head3 cell_unformatted
 
 =over
 
-B<Definition:> This holds the unformatted value stored in the worksheet at that 
-cell.
+B<Definition:> This holds the unformatted value of the cell (if any)
 
-B<Default:> undef (If the cell has formatting but no value then undef will be stored here).
+B<Default:> undef
 
-B<Range:> Any string or number
+B<Range:> a string
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 unformatted
+B<has_unformatted>
 
 =over
 
-B<Definition:> returns this value
+B<Definition:> a predicate method to determine if any value is in the cell
 		
 =back
 
-=head4 has_unformatted
+=back
 
-=over
-
-B<Definition:> check if any value was stored in the cell
-		
 =back
 
 =head3 rich_text
@@ -379,9 +436,9 @@ B<Range:> an array ref of rich_text positions and definitions
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_rich_text
+B<get_rich_text>
 
 =over
 
@@ -389,7 +446,7 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_rich_text
+B<has_rich_text>
 
 =over
 
@@ -397,6 +454,10 @@ B<Definition:> Indicates if the attribute has anything stored
 		
 =back
 
+=back
+
+=back
+
 =head3 cell_font
 
 =over
@@ -409,9 +470,9 @@ B<Range:> a hashref of font definitions
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_font
+B<get_font>
 
 =over
 
@@ -419,7 +480,7 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_font
+B<has_font>
 
 =over
 
@@ -427,6 +488,10 @@ B<Definition:> Indicates if the attribute has anything stored
 		
 =back
 
+=back
+
+=back
+
 =head3 cell_border
 
 =over
@@ -439,9 +504,9 @@ B<Range:> a hashref of border definitions
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_border
+B<get_border>
 
 =over
 
@@ -449,7 +514,7 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_border
+B<has_border>
 
 =over
 
@@ -457,6 +522,10 @@ B<Definition:> Indicates if the attribute has anything stored
 		
 =back
 
+=back
+
+=back
+
 =head3 cell_style
 
 =over
@@ -469,9 +538,9 @@ B<Range:> a hashref of style definitions
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_style
+B<get_style>
 
 =over
 
@@ -479,12 +548,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_style
+B<has_style>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_fill
@@ -499,9 +572,9 @@ B<Range:> a hashref of style definitions
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_fill
+B<get_fill>
 
 =over
 
@@ -509,12 +582,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_fill
+B<has_fill>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_type
@@ -533,9 +610,9 @@ assigned Date conversion, Custom = any stored value with a custom conversion
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 type
+B<type>
 
 =over
 
@@ -543,12 +620,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_type
+B<has_type>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored (Always true)
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_encoding
@@ -563,9 +644,9 @@ B<Range:> Traditional encoding options
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 encoding
+B<encoding>
 
 =over
 
@@ -573,12 +654,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_encoding
+B<has_encoding>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_merge
@@ -595,9 +680,9 @@ B<Range:> two cell ID's
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 merge_range
+B<merge_range>
 
 =over
 
@@ -605,12 +690,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 is_merged
+B<is_merged>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_formula
@@ -626,9 +715,9 @@ B<Range:> Excel formula string
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 formula
+B<formula>
 
 =over
 
@@ -636,12 +725,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_formula
+B<has_formula>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_row
@@ -654,9 +747,9 @@ B<Range:> the minimum row to the maximum row
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 row
+B<row>
 
 =over
 
@@ -664,12 +757,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_row
+B<has_row>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_col
@@ -682,9 +779,9 @@ B<Range:> the minimum column to the maximum column
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 col
+B<col>
 
 =over
 
@@ -692,12 +789,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_col
+B<has_col>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 r
@@ -708,9 +809,9 @@ B<Definition:> This is the sheet ID of the cell
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 cell_id
+B<cell_id>
 
 =over
 
@@ -718,12 +819,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_cell_id
+B<has_cell_id>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_hyperlink
@@ -734,9 +839,9 @@ B<Definition:> This stores any hyperlink from the cell
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_hyperlink
+B<get_hyperlink>
 
 =over
 
@@ -744,12 +849,16 @@ B<Definition:> returns the attribute value
 		
 =back
 
-=head4 has_hyperlink
+B<has_hyperlink>
 
 =over
 
 B<Definition:> Indicates if the attribute has anything stored
 		
+=back
+		
+=back
+		
 =back
 
 =head3 cell_coercion
@@ -769,9 +878,9 @@ identify.
 
 B<attribute methods> Methods provided to adjust this attribute
 		
-=back
+=over
 
-=head4 get_coercion
+B<get_coercion>
 
 =over
 
@@ -779,7 +888,7 @@ B<Definition:> returns this instance
 		
 =back
 
-=head4 clear_coercion
+B<clear_coercion>
 
 =over
 
@@ -787,7 +896,7 @@ B<Definition:> used to clear the this attribute
 		
 =back
 
-=head4 set_coercion
+B<set_coercion>
 
 =over
 
@@ -795,7 +904,7 @@ B<Definition:> used to set a new coercion instance
 		
 =back
 
-=head4 has_coercion
+B<has_coercion>
 
 =over
 
@@ -803,12 +912,16 @@ B<Definition:> Indicate if any coecion code is applied
 		
 =back
 
-=head4 coercion_name
+B<coercion_name>
 
 =over
 
 B<Definition:> calls 'display_name' on the code in the background
 		
+=back
+		
+=back
+		
 =back
 
 =head1 SUPPORT
