@@ -2,7 +2,7 @@ package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet;
 BEGIN {
   $Spreadsheet::XLSX::Reader::LibXML::XMLReader::Worksheet::AUTHORITY = 'cpan:JANDREW';
 }
-use version; our $VERSION = qv('v0.10.6');
+use version; our $VERSION = qv('v0.12.4');
 
 
 use	5.010;
@@ -58,7 +58,7 @@ has workbook_instance =>(
 						get_format_position			set_empty_is_end
 						is_empty_the_end			_starts_at_the_edge
 						get_group_return_type		set_group_return_type
-						get_epoch_year
+						get_epoch_year				change_output_encoding
 					)],
 		handles	=> [qw(
 						counting_from_zero			boundary_flag_setting
@@ -67,7 +67,7 @@ has workbook_instance =>(
 						get_format_position			set_empty_is_end
 						is_empty_the_end			_starts_at_the_edge
 						get_group_return_type		set_group_return_type
-						get_epoch_year
+						get_epoch_year				change_output_encoding
 					)],
 		required => 1,
 	);
